@@ -187,13 +187,15 @@ def get_pieces(
 
         cluster_shares = [
             (f"{'.'.join([parent_label, str(k)])}", len(v))
-            for k, v in clustering_instance._labels.mapping.items()
+            for k, v in sorted(clustering_instance._labels.mapping.items())
             ]
 
         pieces[-1].extend(cluster_shares)
 
         if clustering_instance._children:
-            for child_label, child_clustering in clustering_instance._children.items():
+            for child_label, child_clustering in sorted(
+                    clustering_instance._children.items()):
+
                 if child_clustering._labels is None:
                     continue
 
@@ -209,7 +211,8 @@ def get_pieces(
             for next_parent_label, next_parent_membercount in expected_parent_pool:
                 pieces[-1].append((f"{next_parent_label}.0", next_parent_membercount))
 
-            print(sum(p[1] for p in pieces[-1]))
+            # DEBUG
+            assert sum(p[1] for p in pieces[-1]) == clustering._labels.n_points
 
             if not new_terminal_cluster_references:
                 break
@@ -284,6 +287,7 @@ def plot_summary(
         summary,
         quantity="execution_time",
         treat_nan=None,
+        convert=None,
         contour_props=None):
     """Generate a 2D plot of record values"""
 
@@ -301,6 +305,9 @@ def plot_summary(
     if treat_nan is not None:
         values_[np.isnan(values_)] == treat_nan
 
+    if convert is not None:
+        values_ = np.apply_along_axis(convert, 0, values_)
+
     plotted = []
 
     plotted.append(ax.contourf(X_, Y_, values_, **contour_props))
